@@ -1,4 +1,5 @@
 import {
+  AppEvents,
   DataFrame,
   FieldType,
   getDefaultTimeRange,
@@ -10,6 +11,7 @@ import {
   toDataFrame,
   VisualizationSuggestionScore,
 } from '@grafana/data';
+import { config } from '@grafana/runtime';
 import {
   BarGaugeDisplayMode,
   BigValueColorMode,
@@ -18,10 +20,19 @@ import {
   StackingMode,
   VizOrientation,
 } from '@grafana/schema';
-import { config } from 'app/core/config';
+import { appEvents } from 'app/core/app_events';
+import { clearPanelPluginCache } from 'app/features/plugins/importPanelPlugin';
+import { pluginImporter } from 'app/features/plugins/importer/pluginImporter';
 
 import { panelsToCheckFirst } from './consts';
-import { getAllSuggestions, sortSuggestions } from './getAllSuggestions';
+import { getAllSuggestions, loadPlugins, sortSuggestions } from './getAllSuggestions';
+
+jest.mock('app/core/app_events', () => ({
+  appEvents: {
+    subscribe: jest.fn(() => ({ unsubscribe: jest.fn() })),
+    publish: jest.fn(),
+  },
+}));
 
 config.featureToggles.externalVizSuggestions = true;
 
@@ -52,28 +63,6 @@ for (const pluginId of panelsToCheckFirst) {
   };
 }
 
-config.panels.text = {
-  id: 'text',
-  module: 'core:plugin/text',
-  sort: idx++,
-  name: 'Text',
-  type: PluginType.panel,
-  baseUrl: 'public/app/plugins/panel',
-  skipDataQuery: true,
-  suggestions: false,
-  info: {
-    version: '1.0.0',
-    updated: '2025-01-01',
-    links: [],
-    screenshots: [],
-    author: {
-      name: 'Grafana Labs',
-    },
-    description: 'Text panel',
-    logos: { small: 'small/logo', large: 'large/logo' },
-  },
-};
-
 jest.mock('../state/util', () => {
   const originalModule = jest.requireActual('../state/util');
   return {
@@ -103,7 +92,8 @@ class ScenarioContext {
       timeRange: getDefaultTimeRange(),
     };
 
-    this.suggestions = await getAllSuggestions(panelData);
+    const result = await getAllSuggestions(panelData);
+    this.suggestions = result.suggestions;
   }
 
   names() {
@@ -554,6 +544,81 @@ describe('sortSuggestions', () => {
   });
 });
 
+describe('Visualization suggestions error handling', () => {
+  it('returns result with hasErrors flag', async () => {
+    const result = await getAllSuggestions({
+      series: [
+        toDataFrame({
+          fields: [
+            { name: 'Time', type: FieldType.time, values: [1, 2] },
+            { name: 'Max', type: FieldType.number, values: [1, 10] },
+          ],
+        }),
+      ],
+      state: LoadingState.Done,
+      timeRange: getDefaultTimeRange(),
+    });
+
+    expect(result).toHaveProperty('suggestions');
+    expect(result).toHaveProperty('hasErrors');
+    expect(result.hasErrors).toBe(false);
+  });
+});
+
+// this needs to happen before any
+describe('loadPlugins', () => {
+  beforeEach(() => {
+    clearPanelPluginCache();
+  });
+
+  afterEach(() => {
+    if (jest.isMockFunction(pluginImporter.importPanel)) {
+      jest.mocked(pluginImporter.importPanel).mockRestore();
+    }
+  });
+
+  it('should swallow errors when failing to load core plugins', async () => {
+    jest.spyOn(console, 'error').mockImplementation();
+
+    const _importPanel = pluginImporter.importPanel;
+    jest.spyOn(pluginImporter, 'importPanel').mockImplementation(async (meta) => {
+      if (meta.id === 'timeseries') {
+        throw new Error('Failed to load core panel plugin');
+      }
+      return await _importPanel(meta);
+    });
+
+    const panelIds = ['timeseries', 'table'];
+    const { plugins, hasErrors } = await loadPlugins(panelIds);
+
+    expect(plugins).toEqual([expect.objectContaining({ meta: expect.objectContaining({ id: 'table' }) })]);
+    expect(hasErrors).toBe(true);
+    expect(appEvents.publish).not.toHaveBeenCalled();
+  });
+
+  it('should swallow errors when failing to load external plugins', async () => {
+    jest.spyOn(console, 'error').mockImplementation();
+
+    const panelIds = ['non-existent-panel'];
+    const { plugins, hasErrors } = await loadPlugins(panelIds);
+
+    expect(plugins).toEqual([]);
+    expect(hasErrors).toBe(false);
+    expect(appEvents.publish).toHaveBeenCalledWith({
+      type: AppEvents.alertError.name,
+      payload: [expect.stringContaining('Failed to load panel plugin: non-existent-panel.')],
+    });
+  });
+
+  it('should load panel plugins with suggestions', async () => {
+    const panelIds = ['timeseries', 'table'];
+    const { plugins, hasErrors } = await loadPlugins(panelIds);
+
+    expect(plugins.map((p) => p.meta.id)).toEqual(expect.arrayContaining(['timeseries', 'table']));
+    expect(hasErrors).toBe(false);
+  });
+});
+
 function repeatFrame(count: number, frame: DataFrame): DataFrame[] {
   const frames: DataFrame[] = [];
   for (let i = 0; i < count; i++) {
